clear;      %clear the workspace
clc;        %clear the command window
close all;  %close all the figures

%Presentation of the program
fprintf('aNN prediction \n \n')

%Reading networks
load aNN                                    %loading architecture

%Read the data from EXCEL sheet
in0=xlsread('input-LCS.xls');                   %Original input matrix (without scaling) 1x13


%%%%%%%%Scaling Process%%%%%%%%%%%%%%%%%%
%Applying the scale to the input vector
g=1./in0(:,1);                              %vector of scale factors
in0(:,2)=sqrt(g).*in0(:,2);                 %scaling the Tm-1,0
for z=3:5
    in0(:,z)=g.*in0(:,z);                   %scaling the h, Rc, Wc
end

%Creating the scaled vector
in=zeros(size(in0,1),size(in0,2)-1);        %Input matrix 1x12
n=1;
for z=2:size(in0,2)
    in(:,n)=in0(:,z);
    n=n+1;
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%Auxiliar variables
p=in';                                      %input matrix
boots=size(results.net,2);                  %number of resamples
n=size(p,2);                                %number of tests
A=zeros(boots,n);                           %vector of outputs


%%%%%%%%Ensembling NN's%%%%%%%%%%%%%%%%%%
for i=1:boots
    %Architecture of the network
    net = results.net{i};
    IW  = net.IW{1,1};
    b1  = net.b{1};
    LW  = net.LW{2,1};
    b2  = net.b{2};
    
    %Simulation of the input
    pnew = tramnmx(p,miniP(:,i),maxiP(:,i));
    a=sim(net,pnew);
    A(i,:)=a';    
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%Prediction of aNN%%%%%%%%%%%%%%%%
meanA=mean(A);                              %Kt predicted (mean)
stdA=std(A);                                %Standard deviation of the result
varA=var(A);                                %Variance of the result
q975=quantile(A,0.975);                     %Quantile 97.5%
q75=quantile(A,0.75);                       %Quantile 75%
q50=quantile(A,0.50);                       %Quantile 50%
q25=quantile(A,0.25);                       %Quantile 25%
q025=quantile(A,0.025);                     %Quantile 2.5%

aNN=[meanA stdA varA];                      %Vector of the prediction
aNN1=[q025 q25 q50 q75 q975];               %Vector of quantiles

%Histogram
figure(1)
subplot(1,2,1)
hist(A)
xlabel('Predicted K_t')
ylabel('Number of predictions (from 498)')
title('Histogram of predictions using aNN')

%Boxplot
figure(1)
subplot(1,2,2)
maboxplot(A)
ylabel('K_t')
set(gca,'XTickLabel',{'Box Plot of aNN prediction'})
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%Prediction of DELOS%%%%%%%%%%%%%%
Del=zeros(n,1);
for i=1:n
    Iribarren=(1/p(5,i))/sqrt(1/(1.56*p(1,i)^2));
    %Rubble mound formula
    Kt=-0.4*(p(3,i))+0.64*((p(4,i))^(-0.31))*(1-exp(-0.5*Iribarren));
    Kt1=-0.35*(p(3,i))+0.51*((p(4,i))^(-0.65))*(1-exp(-0.41*Iribarren));
    %Smooth formula
    Kt2=(-0.3*(p(3,i))+0.75*(1-exp(-0.5*Iribarren)))*((cosd(p(6,i)))^(2/3));
    if p(4,i)<8&p(8,i)<1.00                 %Angremond region
        Del(i)=Kt;
    elseif p(4,i)<12&p(8)<1.00              %Transition region
        A=-0.4*(p(3,i))+0.64*((8)^(-0.31))*(1-exp(-0.5*Iribarren));
        B=-0.35*(p(3,i))+0.51*((12)^(-0.65))*(1-exp(-0.41*Iribarren));
        a=(B-A)/4;
        b=3*A-2*B;
        Del(i)=a*p(4,i)+b;
    elseif p(4,i)>=12&p(8,i)<1.00           %Briganti region
        Del(i)=Kt1;
    elseif p(8,i)==1.00                     %Wang prediction
        Del(i)=Kt2;
    end
    if Del(i)>0.93
        Del(i)=-0.006*p(4,i)+0.93;
    elseif Del(i)<0.05
        Del(i)=0.05;
    end
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%Results
disp('Prediction using aNN')
disp('     Mean     St.Dev     Var')
disp(aNN)
disp('     q2.5       q25      q50       q75       q975')
disp(aNN1)
disp('Prediction using DELOS formulae')
disp(Del)