clear;      %clear the workspace
clc;        %clear the command window
close all;  %close all the figures

%Presentation of the program
fprintf('Sensitivity analysis \n \n')

%Reading networks
load aNN                                    %loading architecture

%Read the data from EXCEL sheet
in0=xlsread('input-LCS.xls');                   %Original input matrix (without scaling) 1x9


%%%%%%%%Scaling Process%%%%%%%%%%%%%%%%%%
%Applying the scale to the input vector
g=1./in0(:,1);                              %vector of scale factors
in0(:,2)=sqrt(g).*in0(:,2);                 %scaling the Tm-1,0
for z=3:5
    in0(:,z)=g.*in0(:,z);                   %scaling the h, Rc, Wc
end

%Creating the scaled vector
in=zeros(size(in0,1),size(in0,2)-1);        %Input matrix 1x8
n=1;
for z=2:size(in0,2)
    in(:,n)=in0(:,z);
    n=n+1;
end


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%Selection of the input parameter to be studied
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
disp('the scaled input parameters of the input breakwater are:')
disp(in)
disp('Next we have the input parameters and their code');
fprintf('Tm-1,0=1 h=2 Rc=3 Wc=4 cotuf=5 beta=6 P=7 rf=8\n')
select=input('parameter to study: ');               %parameter to study
iv=input('lower value of the parameter: ');         %initial value in original input
ev=input('higher value of the parameter: ');        %final value in original value
st=input('step of the interval: ');                 %step
    
x=[iv:st:ev];                                       %vector of testing
nt=length(x);                                       %length of the interval
boots=size(results.net,2);                          %number of resamples
A=zeros(boots,1);                                   %vector of outputs
Z=zeros(boots,nt);                                  %matrix of results NN
Del=zeros(nt,1);                                    %matrix of results DELOS
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

counter=1;
for X=iv:st:ev
    p1=in;
    p1(select)=X;
    
    %%%%%%%%Ensembling NN's%%%%%%%%%%%%%%%%%%
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    for i=1:boots
        %Architecture of the network
        net = results.net{i};
        IW  = net.IW{1,1};
        b1  = net.b{1};
        LW  = net.LW{2,1};
        b2  = net.b{2};
        
        %Simulation of the input
        pnew = tramnmx(p1',miniP(:,i),maxiP(:,i));
        a=sim(net,pnew);
        A(i,1)=a;
                 
    end
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    
    Z(:,counter)=A;
    %Empirical formulas
    L0=1.56*p1(1)^2;
    Iribarren=(1/p1(5))/sqrt(1/(L0));
    %Rubble mound formula
    Kt=-0.4*(p1(3))+0.64*((p1(4))^(-0.31))*(1-exp(-0.5*Iribarren));
    Kt1=-0.35*(p1(3))+0.51*((p1(4))^(-0.65))*(1-exp(-0.41*Iribarren));
    %Smooth formula
    Kt2=(-0.3*(p1(3))+0.75*(1-exp(-0.5*Iribarren)))*((cosd(p1(6)))^(2/3));
    if p1(4)<8&p1(8)<1.00                  %Angremond region
        Del(counter)=Kt;
    elseif p1(4)<12&p1(8)<1.00            %Transition region
        A=-0.4*(p1(3))+0.64*((8)^(-0.31))*(1-exp(-0.5*Iribarren));
        B=-0.35*(p1(3))+0.51*((12)^(-0.65))*(1-exp(-0.41*Iribarren));
        a=(B-A)/4;
        b=3*A-2*B;
        Del(counter)=a*p1(4)+b;
    elseif 12<=p1(4)&p1(8)<1.00             %Briganti region
        Del(counter)=Kt1;
    elseif p1(8)==1.00                      %Wang prediction
        Del(counter)=Kt2;
    end
    
    if Del(counter)>0.93
        Del(counter)=-0.006*p1(4)+0.93;
    elseif Del(counter)<0.05
        Del(counter)=0.05;
    end
        
    counter=counter+1;
            
end
    
%Analysis of the output
meanZ=mean(Z);

%Confidence intervals
upper=quantile(Z,0.975);
lower=quantile(Z,0.025);
ci(1,:)=upper;
ci(2,:)=lower;

%Figure
figure(1)
plot(x,meanZ,'k','LineWidth',2)
hold on
plot(x,ci,'--k')
hold on
plot(x,Del,':k')
ylabel('K_t [-]')
if select==1
    xlabel('T_{m-1,0 toe} [s]')
    hold on
    y=[0:1];
    s0=[3.27, 3.27];
    sf=[10.605, 10.605];
    if p1(8)==1
        sf=[7.875, 7.875];
    end
    plot(s0,y,'r',sf,y,'r')
elseif select==2
    xlabel('h / H_{m0 toe} [-]')
    hold on
    y=[0:1];
    s0=[1.55, 1.55];
    sf=[10.92, 10.92];
    if p1(8)==1
        s0=[1.1856, 1.1856];
        sf=[9.7888, 9.7888];
    end
    plot(s0,y,'r',sf,y,'r')
elseif select==3
    xlabel('R_c / H_{m0 toe} [-]')
    hold on
    y=[0:1];
    s0=[-3.48, -3.48];
    sf=[2.27, 2.27];
    if p1(8)==1
        s0=[-2.044, -2.044];
        sf=[0.704, 0.704];
    end
    plot(s0,y,'r',sf,y,'r')
elseif select==4
    xlabel('W_c / H_{m0 toe} [-]')
    %x=L0.\x;
    %figure(2)
    %plot(x,meanZ,'k','LineWidth',2)
    %hold on
    %plot(x,ci,'--k')
    %hold on
    %plot(x,Del,':k')
    %ylabel('K_t [-]')
    %xlabel('W_c / L_{0 toe} [-]')
    hold on
    y=[0:1];
    s0=[0.009, 0.009];
    sf=[47.17, 47.17];
    if p1(8)==1
        s0=[0.6173, 0.6173];
        sf=[5.9648, 5.9648];
    end
    plot(s0,y,'r',sf,y,'r')
elseif select==5
    xlabel('cot \alpha_{u f} [-]')
    hold on
    y=[0:1];
    s0=[1, 1];
    sf=[5, 5];
    plot(s0,y,'r',sf,y,'r')
elseif select==6
    xlabel('\beta []')
    if p1(8)<1
        hold on
        y=[0:1];
        s0=[45, 45];
        plot(s0,y,'r')
    end
elseif select==7
    xlabel('Notional permeability P [-]')
elseif select==8
    xlabel('\gamma_f [-]')
    hold on
    y=[0:1];
    s0=[0.38, 0.38];
    sf=[0.90, 0.90];
    plot(s0,y,'r',sf,y,'r')
    
end
